#[non_exhaustive]pub enum RegistriesProtocol {
Git,
Sparse,
}Expand description
Specifies the protocol used to access crates.io.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Git
Causes Cargo to clone the entire index of all packages ever published to crates.io from https://github.com/rust-lang/crates.io-index/.
Sparse
A newer protocol which uses HTTPS to download only what is necessary from https://index.crates.io/.