CredentialProvider

Enum CredentialProvider 

#[non_exhaustive]
pub enum CredentialProvider { CargoToken, CargoWincred, CargoMacosKeychain, CargoLibsecret, CargoTokenFromStdout(PathAndArgs), Plugin(PathAndArgs), Alias(String), }
The kind of a registry’s credential provider.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


CargoToken

Uses Cargo’s credentials file to store tokens unencrypted in plain text.

Cargo Reference



CargoWincred

Uses the Windows Credential Manager to store tokens.

Cargo Reference



CargoMacosKeychain

Uses the macOS Keychain to store tokens.

Cargo Reference



CargoLibsecret

Uses libsecret to store tokens.

Cargo Reference



CargoTokenFromStdout(PathAndArgs)

Launch a subprocess that returns a token on stdout. Newlines will be trimmed.

Cargo Reference



Plugin(PathAndArgs)

For credential provider plugins that follow Cargo’s credential provider protocol, the configuration value should be a string with the path to the executable (or the executable name if on the PATH).

Cargo Reference



Alias(String)

An alias, to be looked up in the [credential-alias] table.