#[non_exhaustive]pub struct FutureIncompatReportConfig {
pub frequency: Option<Frequency>,
}Expand description
The [future-incompat-report] table.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.frequency: Option<Frequency>Controls how often we display a notification to the terminal when a future incompat report is available.