#[non_exhaustive]pub struct RegistryConfig {
pub default: Option<String>,
pub credential_provider: Option<CredentialProvider>,
pub token: Option<String>,
pub global_credential_providers: GlobalCredentialProviders,
}Expand description
The [registry] table.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.default: Option<String>The name of the registry (from the
registries table)
to use by default for registry commands like
cargo publish.
credential_provider: Option<CredentialProvider>Specifies the credential provider for crates.io. If not set, the providers in
registry.global-credential-providers
will be used.
token: Option<String>Specifies the authentication token for crates.io.
Note: This library does not read any values in the credentials file.
global_credential_providers: GlobalCredentialProvidersSpecifies the list of global credential providers.
If credential provider is not set for a specific registry using
registries.<name>.credential-provider,
Cargo will use the credential providers in this list.
Providers toward the end of the list have precedence.