ResolveOptions

Struct ResolveOptions 

pub struct ResolveOptions { /* private fields */ }

Implementations

Source

impl ResolveOptions

pub fn rustc<P: Into<PathAndArgs>>(self, rustc: P) -> Self

Sets rustc path and args.

Default value

Config::rustc

pub fn cargo<S: Into<OsString>>(self, cargo: S) -> Self

Sets cargo path.

Default value

The value of the CARGO environment variable if it is set. Otherwise, “cargo”.

pub fn cargo_home<P: Into<Option<PathBuf>>>(self, cargo_home: P) -> Self

Sets CARGO_HOME path.

Default value

home::cargo_home_with_cwd if the current directory was specified when loading config. Otherwise, home::cargo_home.

pub fn host_triple<S: Into<String>>(self, triple: S) -> Self

Sets host target triple.

Default value

Parse the version output of cargo specified by Self::cargo.

pub fn env<I: IntoIterator<Item = (K, V)>, K: Into<OsString>, V: Into<OsString>>( self, vars: I, ) -> Self

Sets the specified key-values as environment variables to be read during config resolution.

This is mainly intended for use in tests where it is necessary to adjust the kinds of environment variables that are referenced.

Default value

std::env::vars_os