#[non_exhaustive]pub struct TermConfig {
pub quiet: Option<bool>,
pub verbose: Option<bool>,
pub color: Option<Color>,
pub progress: TermProgressConfig,
}Expand description
The [term] table.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.quiet: Option<bool>Controls whether or not log messages are displayed by Cargo.
verbose: Option<bool>Controls whether or not extra detailed messages are displayed by Cargo.
color: Option<Color>Controls whether or not colored output is used in the terminal.
progress: TermProgressConfigTrait Implementations
Sourceimpl Clone for TermConfig
impl Clone for TermConfig
Sourcefn clone(&self) -> TermConfig
fn clone(&self) -> TermConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TermConfig
impl Debug for TermConfig
Sourceimpl Default for TermConfig
impl Default for TermConfig
Sourcefn default() -> TermConfig
fn default() -> TermConfig
Returns the “default value” for a type. Read more