#[non_exhaustive]pub struct BuildConfig {
pub jobs: Option<i32>,
pub rustc: Option<PathBuf>,
pub rustc_wrapper: Option<PathBuf>,
pub rustc_workspace_wrapper: Option<PathBuf>,
pub rustdoc: Option<PathBuf>,
pub target: Option<Vec<TargetTriple>>,
pub target_dir: Option<PathBuf>,
pub build_dir: Option<PathBuf>,
pub rustflags: Option<Flags>,
pub rustdocflags: Option<Flags>,
pub incremental: Option<bool>,
pub dep_info_basedir: Option<PathBuf>,
/* private fields */
}Expand description
The [build] table.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.jobs: Option<i32>Sets the maximum number of compiler processes to run in parallel. If negative, it sets the maximum number of compiler processes to the number of logical CPUs plus provided value. Should not be 0.
rustc: Option<PathBuf>Sets the executable to use for rustc.
Note: If a wrapper is set, cargo’s actual rustc call goes through
the wrapper, so you may want to use Config::rustc, which respects
that behavior instead of referencing this value directly.
rustc_wrapper: Option<PathBuf>Sets a wrapper to execute instead of rustc.
Note: If a wrapper is set, cargo’s actual rustc call goes through
the wrapper, so you may want to use Config::rustc, which respects
that behavior instead of referencing this value directly.
rustc_workspace_wrapper: Option<PathBuf>Sets a wrapper to execute instead of rustc, for workspace members only.
Note: If a wrapper is set, cargo’s actual rustc call goes through
the wrapper, so you may want to use Config::rustc, which respects
that behavior instead of referencing this value directly.
rustdoc: Option<PathBuf>Sets the executable to use for rustdoc.
target: Option<Vec<TargetTriple>>The default target platform triples to compile to.
target_dir: Option<PathBuf>The path to where all compiler output is placed. The default if not specified is a directory named target located at the root of the workspace.
build_dir: Option<PathBuf>The path to where all compiler intermediate artifacts are placed. The default if not specified is the value of build.target-dir
Note: If a template variable is used the path will be unresolved. For available template variables see the Cargo reference.
rustflags: Option<Flags>Extra command-line flags to pass to rustc. The value may be an array of strings or a space-separated string.
Note: This field does not reflect the target-specific rustflags
configuration, so you may want to use Config::rustflags which respects
the target-specific rustflags configuration.
rustdocflags: Option<Flags>Extra command-line flags to pass to rustdoc. The value may be an array
of strings or a space-separated string.
Note: This field does not reflect the target-specific rustdocflags
configuration, so you may want to use Config::rustdocflags which respects
the target-specific rustdocflags configuration.
incremental: Option<bool>Whether or not to perform incremental compilation.
dep_info_basedir: Option<PathBuf>Strips the given path prefix from dep info file paths.